@@ -1,12 +1,12 @@
 from pyg_base._as_float import as_float
 from pyg_base._as_list import as_list, as_tuple, first, last, passthru, unique, is_rng
 from pyg_base._as_primitive import as_primitive
-from pyg_base._cache import cache, get_cache
+from pyg_base._cache import cache, get_cache, cache_func
 from pyg_base._cfg import mkdir, cfg_read, cfg_write, CFG
 from pyg_base._dates import iso, dt, uk2dt, us2dt, dt_bump, as_tz, tz_convert, today, ymd, TMIN, TMAX, DAY, futcodes, dt2str, is_bump, nth_weekday_of_month, mmm2m
 from pyg_base._decorators import kwargs_support, wrapper, try_value, try_back, try_nan, try_none, try_zero, try_false, try_true, try_list, timer
 from pyg_base._dict import Dict, items_to_tree, tree_items, tree_keys, tree_values, tree_setitem, tree_getitem, tree_get, tree_update, dict_invert
-from pyg_base._dictattr import dictattr, relabel
+from pyg_base._dictattr import dictattr, relabel, getattrs
 from pyg_base._dictable import dictable, dict_concat, is_dictable
 from pyg_base._drange import date_range, drange, calendar, Calendar, clock, as_time
 from pyg_base._eq import eq, in_
@@ -14,7 +14,7 @@ from pyg_base._file import read_csv
 from pyg_base._getitem import getitem, callitem, callattr
 from pyg_base._inspect import getargspec, getargs, getcallargs, getcallarg, call_with_callargs, argspec_defaults, argspec_required, argspec_update, argspec_add, kwargs2args
 from pyg_base._logger import logger, get_logger
-from pyg_base._loop import loop, loops, len0, pd2np, shape, loop_all, skip_if_data_pd, skip_if_data_pd_or_np
+from pyg_base._loop import loop, loops, len0, pd2np, shape, loop_all, skip_if_data_pd, skip_if_data_pd_or_np, grab_parameter_from_dict
 from pyg_base._named_dict import named_dict
 from pyg_base._pandas import df_index, df_columns, df_reindex, np_reindex, df_recolumn, df_concat, df_fillna, presync, df_sync, df_apply, \
     add_, sub_, mul_, div_, pow_, df_slice, df_unslice, nona, min_, max_, gt_, ge_, lt_, le_, df_count, df_sum, df_mean, df_std
@@ -25,7 +25,7 @@ from pyg_base._tree import is_tree, tree_to_table
 from pyg_base._tree_repr import tree_repr
 from pyg_base._txt import alphabet, ALPHABET, f12, as_ascii, replace, relabel_lower, lower, upper, proper, strip, split, capitalize, common_prefix, deprefix
 from pyg_base._types import is_pd, is_arr, is_int, is_float, is_num, is_bool, is_str, is_nan, \
-    is_none, is_dict, is_iterable, is_date, is_df, is_series, is_ts, is_list, is_tuple,\
+    is_none, is_dict, is_iterable, is_date, is_df, is_series, is_ts, is_list, is_tuple, is_primitive, \
     is_pds, is_arrs, is_ints, is_floats, is_nums, is_len, is_bools, is_strs, is_nans, is_nones, is_dicts, is_zero_len, \
     is_iterables, is_tss, nan2none, NoneType, is_dates, is_lists, list_instances
 from pyg_base._ulist import ulist, rng
