@@ -1,6 +1,7 @@
 import os
 import json
-CFG = os.environ.get('PYG_CFG', 'c:/etc/pyg.json')
+CFG = os.environ.get('PYG_CFG', 'e:/etc/pyg.json')
+_backup = 'c:/etc/pyg.json'
 
 def mkdir(path):
     """
@@ -29,10 +30,11 @@ def mkdir(path):
     return path
 
 def cfg_read():
-    if os.path.isfile(CFG):
-        with open(CFG, 'r') as f:
-            cfg = json.load(f)
-        return cfg
+    for path in [CFG, _backup]:
+        if os.path.isfile(path):
+            with open(path, 'r') as f:
+                cfg = json.load(f)
+            return cfg
     else:
         return {}
 cfg_read.__doc__ = 'reads the config file from %s' % CFG
@@ -40,8 +42,12 @@ cfg_read.__doc__ = 'reads the config file from %s' % CFG
 
 
 def cfg_write(cfg):
-    with open(mkdir(CFG), 'w') as f:
-        json.dump(cfg, f)
+    try:
+        with open(mkdir(CFG), 'w') as f:
+            json.dump(cfg, f)
+    except Exception:
+        with open(mkdir(_backup), 'w') as f:
+            json.dump(cfg, f)
         
 cfg_write.__doc__ = 'writes the config file provided to %s' % CFG
     
