@@ -3,6 +3,7 @@ import numpy as np
 from _collections_abc import Iterable, dict_keys, dict_values
 import datetime
 from functools import partial
+from enum import Enum
 
 from pyg_base._logger import logger
 
@@ -14,6 +15,11 @@ NoneType = type(None)
 
 
 
+_primitives =  (int, np.int64, np.int32, np.int16, np.int8, float, np.float16, np.float32, np.float64, bool, np.bool_, str, np.str_, Enum, datetime.date, datetime.datetime, np.datetime64) 
+                
+def is_primitive(value):
+    value is None or isinstance(value, _primitives)
+
 def is_series(value):
     """ is value a pd.Series"""
     return isinstance(value, pd.Series)
